@@ -329,10 +329,10 @@ typedef struct _HsaNodeProperties
     HSAuint32       VGPRSizePerCU;     // VGPR size in bytes per CU
     HSAuint32       SGPRSizePerCU;     // SGPR size in bytes per CU
 
+    HSAuint32       NumXcc;            // Number of XCC
     HSAuint32       KFDGpuID;          // GPU Hash ID generated by KFD
 
     HSAuint32       FamilyID;          // GPU family id
-    HSAuint8        Reserved[4];
 } HsaNodeProperties;
 
 
@@ -564,7 +564,10 @@ typedef struct _HsaMemFlags
             unsigned int FixedAddress : 1; // Allocate memory at specified virtual address. Fail if address is not free.
             unsigned int NoNUMABind:    1; // Don't bind system memory to a specific NUMA node
             unsigned int Uncached:      1; // Caching flag for fine-grained memory on A+A HW platform
-            unsigned int Reserved    : 14;
+            unsigned int NoAddress:     1; // only do vram allocation, return a handle, not allocate virtual address.
+            unsigned int OnlyAddress:   1; // only do virtal address allocation without vram allocation.
+            unsigned int ExtendedCoherent: 1;  // system-scope coherence on atomic instructions
+            unsigned int Reserved:     11;
 
         } ui32;
         HSAuint32 Value;
@@ -605,7 +608,7 @@ typedef struct _HsaGraphicsResourceInfo {
     HSAuint64  SizeInBytes;         // Buffer size
     const void *Metadata;           // Pointer to metadata owned by Thunk
     HSAuint32  MetadataSizeInBytes; // Size of metadata
-    HSAuint32  Reserved;            // Reserved for future use, will be set to 0
+    HSAuint32  NodeId;              // GPU exported the buffer
 } HsaGraphicsResourceInfo;
 
 typedef enum _HSA_CACHING_TYPE
@@ -834,6 +837,40 @@ typedef enum _HSA_DBG_TRAP_MASK
   HSA_DBG_TRAP_MASK_DBG_MEMORY_VIOLATION = 256  // Memory violation
 } HSA_DBG_TRAP_MASK;
 
+typedef enum _HSA_DBG_TRAP_EXCEPTION_CODE {
+	HSA_DBG_EC_NONE = 0,
+	/* per queue */
+	HSA_DBG_EC_QUEUE_WAVE_ABORT = 1,
+	HSA_DBG_EC_QUEUE_WAVE_TRAP = 2,
+	HSA_DBG_EC_QUEUE_WAVE_MATH_ERROR = 3,
+	HSA_DBG_EC_QUEUE_WAVE_ILLEGAL_INSTRUCTION = 4,
+	HSA_DBG_EC_QUEUE_WAVE_MEMORY_VIOLATION = 5,
+	HSA_DBG_EC_QUEUE_WAVE_APERTURE_VIOLATION = 6,
+	HSA_DBG_EC_QUEUE_PACKET_DISPATCH_DIM_INVALID = 16,
+	HSA_DBG_EC_QUEUE_PACKET_DISPATCH_GROUP_SEGMENT_SIZE_INVALID = 17,
+	HSA_DBG_EC_QUEUE_PACKET_DISPATCH_CODE_INVALID = 18,
+	HSA_DBG_EC_QUEUE_PACKET_RESERVED = 19,
+	HSA_DBG_EC_QUEUE_PACKET_UNSUPPORTED = 20,
+	HSA_DBG_EC_QUEUE_PACKET_DISPATCH_WORK_GROUP_SIZE_INVALID = 21,
+	HSA_DBG_EC_QUEUE_PACKET_DISPATCH_REGISTER_INVALID = 22,
+	HSA_DBG_EC_QUEUE_PACKET_VENDOR_UNSUPPORTED = 23,
+	HSA_DBG_EC_QUEUE_PREEMPTION_ERROR = 30,
+	HSA_DBG_EC_QUEUE_NEW = 31,
+	/* per device */
+	HSA_DBG_EC_DEVICE_QUEUE_DELETE = 32,
+	HSA_DBG_EC_DEVICE_MEMORY_VIOLATION = 33,
+	HSA_DBG_EC_DEVICE_RAS_ERROR = 34,
+	HSA_DBG_EC_DEVICE_FATAL_HALT = 35,
+	HSA_DBG_EC_DEVICE_NEW = 36,
+	/* per process */
+	HSA_DBG_EC_PROCESS_RUNTIME = 48,
+	HSA_DBG_EC_PROCESS_DEVICE_REMOVE = 49,
+	HSA_DBG_EC_MAX
+} HSA_DBG_TRAP_EXCEPTION_CODE;
+
+/* Mask generated by ecode defined in enum above. */
+#define HSA_EC_MASK(ecode)	(1ULL << (ecode - 1))
+
 typedef enum _HSA_DBG_WAVE_LAUNCH_MODE
 {
     HSA_DBG_WAVE_LAUNCH_MODE_NORMAL      = 0, // Wavefront launched normally.
@@ -857,6 +894,7 @@ typedef enum HSA_DBG_NODE_CONTROL {
     HSA_DBG_NODE_CONTROL_FLAG_MAX = 0x01
 } HSA_DBG_NODE_CONTROL;
 
+#define HSA_RUNTIME_ENABLE_CAPS_SUPPORTS_CORE_DUMP_MASK 0x80000000
 
 //This structure is hardware specific and may change in the future
 typedef struct _HsaDbgWaveMsgAMDGen2
@@ -1006,6 +1044,21 @@ typedef struct _HsaMemoryAccessFault
     HSA_EVENTID_MEMORYFLAGS         Flags;              // event flags
 } HsaMemoryAccessFault;
 
+typedef enum _HSA_EVENTID_HW_EXCEPTION_CAUSE
+{
+    HSA_EVENTID_HW_EXCEPTION_GPU_HANG  = 0, // GPU Hang
+    HSA_EVENTID_HW_EXCEPTION_ECC       = 1, // SRAM ECC error
+} HSA_EVENTID_HW_EXCEPTION_CAUSE;
+
+// data associated with HSA_EVENTID_HW_EXCEPTION
+typedef struct _HsaHwException
+{
+    HSAuint32                       NodeId;    // Node Id where the memory exception occured
+    HSAuint32                       ResetType;
+    HSAuint32                       MemoryLost;
+    HSA_EVENTID_HW_EXCEPTION_CAUSE  ResetCause;
+} HsaHwException;
+
 typedef struct _HsaEventData
 {
     HSA_EVENTTYPE   EventType;      //event type
@@ -1024,6 +1077,8 @@ typedef struct _HsaEventData
         // data associated with HSA_EVENTTYPE_MEMORY
         HsaMemoryAccessFault    MemoryAccessFault;
 
+        // data associated with HSA_EVENTTYPE_HW_EXCEPTION
+        HsaHwException          HwException;
     } EventData;
 
     // the following data entries are internal to the KFD & thunk itself.
@@ -1301,8 +1356,9 @@ typedef enum _HSA_POINTER_TYPE {
     HSA_POINTER_ALLOCATED = 1,           // Allocated with hsaKmtAllocMemory (except scratch)
     HSA_POINTER_REGISTERED_USER = 2,     // Registered user pointer
     HSA_POINTER_REGISTERED_GRAPHICS = 3, // Registered graphics buffer
-    HSA_POINTER_REGISTERED_SHARED = 4    // Registered shared buffer (IPC)
+    HSA_POINTER_REGISTERED_SHARED = 4,   // Registered shared buffer (IPC)
                                          // (hsaKmtRegisterGraphicsToNodes)
+    HSA_POINTER_RESERVED_ADDR = 5        // address-only reservation VA
 } HSA_POINTER_TYPE;
 
 typedef struct _HsaPointerInfo {
@@ -1334,6 +1390,7 @@ typedef enum _HSA_SVM_FLAGS {
 	HSA_SVM_FLAG_GPU_EXEC    = 0x00000010, // Allow execution on GPU
 	HSA_SVM_FLAG_GPU_READ_MOSTLY = 0x00000020, // GPUs mostly read, may allow similar optimizations as RO, but writes fault
 	HSA_SVM_FLAG_GPU_ALWAYS_MAPPED = 0x00000040, // Keep GPU memory mapping always valid as if XNACK is disable
+	HSA_SVM_FLAG_EXT_COHERENT = 0x00000080, //  Fine grained coherency between all devices using device-scope atomics
 } HSA_SVM_FLAGS;
 
 typedef enum _HSA_SVM_ATTR_TYPE {
@@ -1406,6 +1463,8 @@ typedef enum _HSA_SVM_UNMAP_TRIGGERS {
 #define HSA_SMI_EVENT_MASK_FROM_INDEX(i) (1ULL << ((i) - 1))
 #define HSA_SMI_EVENT_MSG_SIZE	96
 
+typedef void *HsaAMDGPUDeviceHandle;
+
 #pragma pack(pop, hsakmttypes_h)
 
 
